@@ -62,7 +62,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
             expire_on_candle_close = expire_on_candle_closes[i]
             yf_lag = yf_lags[i]
             answer = answers[i]
-            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
             try:
                 self.assertEqual(response, answer)
             except:
@@ -134,7 +134,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
             expire_on_candle_close = expire_on_candle_closes[i]
             yf_lag = yf_lags[i]
             answer = answers[i]
-            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
             try:
                 self.assertEqual(response, answer)
             except:
@@ -166,7 +166,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
         dt_now = friday_midnight_dt+timedelta(minutes=14)
         expire_on_candle_close = False
         answer = True
-        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
         try:
             self.assertEqual(result, answer)
         except:
@@ -179,7 +179,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
         #
         dt_now = friday_midnight_dt+timedelta(minutes=2)
         answer = False
-        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
         try:
             self.assertEqual(result, answer)
         except:
@@ -194,7 +194,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
         max_age = timedelta(hours=1)
         expire_on_candle_close = True
         answer = True
-        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
         try:
             self.assertEqual(result, answer)
         except:
@@ -211,7 +211,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
         dt_now = friday_midnight_dt+yf_lag+timedelta(minutes=14)
         expire_on_candle_close = False
         answer = False
-        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+        result = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
         try:
             self.assertEqual(result, answer)
         except:
@@ -249,7 +249,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
             expire_on_candle_close = expire_on_candle_closes[i]
             yf_lag = yf_lags[i]
             answer = answers[i]
-            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
             try:
                 self.assertEqual(response, answer)
             except:
@@ -290,7 +290,7 @@ class Test_PriceDataAging_1W(unittest.TestCase):
             expire_on_candle_close = expire_on_candle_closes[i]
             yf_lag = yf_lags[i]
             answer = answers[i]
-            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, expire_on_candle_close, yf_lag, dt_now)
+            response = yfct.IsPriceDatapointExpired(interval_start, fetch_dt, max_age, self.exchange, interval, triggerExpiryOnClose=expire_on_candle_close, yf_lag=yf_lag, dt_now=dt_now)
             try:
                 self.assertEqual(response, answer)
             except:
